@@ -26,7 +26,6 @@ ARGUMENT_RENAMES = {
     'ec2.create-image.no-no-reboot': 'reboot',
     'ec2.*.no-egress': 'ingress',
     'ec2.*.no-disable-api-termination': 'enable-api-termination',
-    'elastictranscoder.*.output': 'job-output',
     'swf.register-activity-type.version': 'activity-version',
     'swf.register-workflow-type.version': 'workflow-version',
     'datapipeline.*.query': 'objects-query',
@@ -95,6 +94,7 @@ ARGUMENT_RENAMES = {
     'eks.update-cluster-version.version': 'kubernetes-version',
     'eks.create-nodegroup.version': 'kubernetes-version',
     'eks.update-nodegroup-version.version': 'kubernetes-version',
+    'eks.update-cluster-components-version.version': 'kubernetes-version',
     'schemas.*.version': 'schema-version',
     'sagemaker.delete-image-version.version': 'version-number',
     'sagemaker.describe-image-version.version': 'version-number',
